==> quanta-3.1.tar.bz2: quanta-3.1/quanta/tagdialogs/colorcombo.h <==
/* This file is part of the KDE libraries
    Copyright (C) 1997 Martin Jones (mjones@kde.org)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//-----------------------------------------------------------------------------
// KDE color selection combo box

// layout managment added Oct 1997 by Mario Weilguni 
// <mweilguni@sime.com>


#ifndef _COLORCOMBO_H__
#define _COLORCOMBO_H__

#include <qcombobox.h>
#include <kdialogbase.h>
#include <qframe.h>
#include <qpixmap.h>
#include <kcolordlg.h>
#include "kselect.h"


/**
 * Combobox for colours.
 */
class ColorCombo : public QComboBox
{
	Q_OBJECT
public:
	ColorCombo( QWidget *parent = 0L, const char *name = 0L );
	~ColorCombo();

	void setColor( const QColor &col );
	void setColorName(QString color);
	QString colorName();
	/** 
	 * Retrieve the currently selected color. 
	 **/
	QColor color();
	
	bool hasColor();
    
public slots:
	void slotActivated( int index );
	void slotHighlighted( int index );

signals:
	void activated( const QColor &col );
	void highlighted( const QColor &col );

protected:
        /**
         * @reimplemented
         */
	virtual void resizeEvent( QResizeEvent *re );

private:
	void createStandardPalette();
	void addColors();
	QColor customColor;
	QColor internalcolor;
	
	bool hascolor;
	
  QColor *standardPalette;
	QString *standardPaletteNames;

    
};

#endif	// __COLORCOMBO_H__

==> quanta-3.1.4.tar.bz2: quanta-3.1.4/quanta/tagdialogs/colorcombo.h <==
/* This file is part of the KDE libraries
    Copyright (C) 1997 Martin Jones (mjones@kde.org)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//-----------------------------------------------------------------------------
// KDE color selection combo box

// layout managment added Oct 1997 by Mario Weilguni 
// <mweilguni@sime.com>


#ifndef _COLORCOMBO_H__
#define _COLORCOMBO_H__

#include <qcombobox.h>
#include <kdialogbase.h>
#include <qframe.h>
#include <qpixmap.h>
#include <kcolordialog.h>
#include "kselect.h"


/**
 * Combobox for colours.
 */
class ColorCombo : public QComboBox
{
	Q_OBJECT
public:
	ColorCombo( QWidget *parent = 0L, const char *name = 0L );
	~ColorCombo();

	void setColor( const QColor &col );
	void setColorName(QString color);
	QString colorName();
	/** 
	 * Retrieve the currently selected color. 
	 **/
	QColor color();
	
	bool hasColor();
    
public slots:
	void slotActivated( int index );
	void slotHighlighted( int index );

signals:
	void activated( const QColor &col );
	void highlighted( const QColor &col );

protected:
        /**
         * @reimplemented
         */
	virtual void resizeEvent( QResizeEvent *re );

private:
	void createStandardPalette();
	void addColors();
	QColor customColor;
	QColor internalcolor;
	
	bool hascolor;
	
  QColor *standardPalette;
	QString *standardPaletteNames;

    
};

#endif	// __COLORCOMBO_H__
